Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/configuraptor/__about__.py | 1 | 0 | 0 | 100%
src/configuraptor/__init__.py | 3 | 0 | 0 | 100%
src/configuraptor/cls.py | 7 | 0 | 0 | 100%
src/configuraptor/core.py | 145 | 0 | 3 | 100%
src/configuraptor/errors.py | 26 | 0 | 0 | 100%
src/configuraptor/helpers.py | 2 | 0 | 0 | 100%
src/configuraptor/loaders/__init__.py | 14 | 0 | 2 | 100%
src/configuraptor/loaders/_types.py | 4 | 0 | 0 | 100%
src/configuraptor/loaders/loaders_310.py | 5 | 0 | 6 | 100%
src/configuraptor/loaders/loaders_311.py | 6 | 0 | 2 | 100%
src/configuraptor/loaders/loaders_shared.py | 10 | 0 | 0 | 100%
src/configuraptor/singleton.py | 13 | 0 | 0 | 100%
Total | 236 | 0 | 13 | 100%

No items found using the specified filter.